Crate md_icons

Crate md_icons 

Crate for using material design (SVG-) icons from https://github.com/marella/material-design-icons as String constants or as maud components.

The icons have four different style: filled, outlined, sharp or two_tone. These are directly represented as modules in this crate. You can get an overview of the icons at Google fonts.

Example

Get the SVG as a string:

let hamburger_menu = md_icons::outlined::ICON_MENU;

… or get it as a maud::Markup with the maud feature enabled:

let hamburger_menu = md_icons::outlined::maud_icon_menu();

Modules

filled
outlined
Outlined icons. See https://fonts.google.com/icons?icon.style=Outlined
sharp
Sharp icons. See https://fonts.google.com/icons?icon.style=Sharp
two_tone